Lua_MainLineDownPanel = class("Lua_MainLineDownPanel", Lua_DisplayObject);
function Lua_MainLineDownPanel:ctor(p)
	self:superCall("ctor", p, "MainLineDownPanel_skin");
end

function Lua_MainLineDownPanel:buildShowItem()
	self:superCall("buildShowItem");
	self.canShow = true
	self.canFight = true
	self.recordId = 0

	self:addLuaEvent("FIGHTPLAY_ENTER", self, self.checkIsFighting);
	self:addLuaEvent("FIGHTPLAY_COMPLETE", self, self.checkIsFighting);
	self:addLuaEvent("UPDATE_ROLE_LEVEL", self, self.updateShowInfo);
	self:addLuaEvent("UPDATE_TASK_STATE", self, self.ckeckExploreState);

	self.redPoint_fastFight = Lua_RedPointIcon.new(self.content, Lua_RedPointList.MainLine_FastFight);
	self.redPoint_fastFight:setLocation(310, 190, 0);

	self.btnFight:addClickFuntion(self, self.onFightClick);
	self.btnFastFight:addClickFuntion(self, self.onFastFightClick);

	self:ckeckExploreState();
end

function Lua_MainLineDownPanel:dispose()
	DataCenter.preLoadData:removeBySign("Lua_FightLineupWindow", self, self.onSceneShow);
	if self.redPoint_fastFight ~= nil then
		self.redPoint_fastFight:dispose();
		self.redPoint_fastFight = nil;
	end
	if self.btnEff then
		self.btnEff:dispose();
		self.btnEff = nil;
	end
	if self.fightEff then
		self.fightEff:dispose();
		self.fightEff = nil;
	end
	if self.exploreBtn then
		self.exploreBtn:dispose();
		self.exploreBtn = nil;
	end
	if self.exploreRedDot then
		self.exploreRedDot:dispose();
		self.exploreRedDot = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_MainLineDownPanel:setBtnEnable(bEnable)
	self.btnEnable = bEnable
	if bEnable then
		self.btnFight:setEnable(self.canShow);
		self:showEffect(self.canShow and self.canFight and self.recordId == 0);
		self:showFightEff(self.canShow and self.canFight and self.recordId > 0);
	else
		self.btnFight:setEnable(false);
		self:showEffect(false);
		self:showFightEff(false);
	end
end

function Lua_MainLineDownPanel:setData(data)
	self.data = data;
	self:updateShowInfo();
end

function Lua_MainLineDownPanel:checkIsFighting(templateId)
	if templateId == DataCenter.mainLineData.curTemplateId then
		self:updateShowInfo();
	end
end

function Lua_MainLineDownPanel:updateShowInfo()
	self.canShow = true
	self.canFight = true
	self.recordId = DataCenter.fightData:getRecordIdByTemplateId(DataCenter.mainLineData.curTemplateId);
	if self.recordId > 0 then
		self.btnFight:setLangValue(307046);
	else
		local bCompleted = DataCenter.mainLineData:getCheckpointIsCompleted(self.data.checkpointId);
		if bCompleted then
			if self.data.next_game_level_id == 0 then
				self.canShow = false
				self.btnFight:setLangValue(307005);
			else
				self.btnFight:setLangValue(307006);
			end
		else
			if self.data.open_level > DataCenter.roleData.level then
				self.canFight = false
				self.btnFight.label = LanUtil.formateStr(307007, tostring(self.data.open_level));
			else
				-- if self.data.is_boss == 1 then
				-- 	self.btnFight:setLangValue(307008);
				-- else
				-- 	self.btnFight:setLangValue(307009);
				-- end
				self.btnFight:setLangValue(307009);
			end
		end
	end

	self.btnFight:setEnable(self.btnEnable and self.canShow)
	self:showEffect(self.btnEnable and self.canShow and self.canFight and self.recordId == 0)
	self:showFightEff(self.btnEnable and self.canShow and self.canFight and self.recordId > 0)
end

function Lua_MainLineDownPanel:showEffect(value)
	if value then
		if self.btnEff == nil then
			self.btnEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_zx_tiaozhan_1", "ui_zx_tiaozhan_1", 12, 165)
		end
		self.btnEff:setEnable(true)
	else
		if self.btnEff then
			self.btnEff:setEnable(false)
		end
	end
end

function Lua_MainLineDownPanel:showFightEff(value)
	if value then
		if self.fightEff == nil then
			self.fightEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_ty_zdbs_0101", "ui_ty_zdbs_0101", -57, 175)
			self.fightEff:setScale(0.5, 0.5, 0.5)
		end
		self.fightEff:setEnable(true)
	else
		if self.fightEff then
			self.fightEff:setEnable(false)
		end
	end
end

function Lua_MainLineDownPanel:onFightClick(go)
	if self.recordId > 0 then
		DataCenter.fightData:showFightToStageByRid(self.recordId);
		return;
	end
	
	if self.data == nil then
		return;
	end

	local bCompleted = DataCenter.mainLineData:getCheckpointIsCompleted(self.data.checkpointId);
	if bCompleted then
		if self.data.next_game_level_id > 0 then
			Lua_WindowUtil.openWin("Lua_MainLineNewChapterWindow", Lua_WinParam.ACTION_OPEN, self.data.next_game_level_id);
		end
	else
		if self.data.open_level > DataCenter.roleData.level then
			Lua_WindowUtil.openWin("Lua_MainLinePlayWindow", Lua_WinParam.ACTION_OPEN, self.data.open_level);
			return;
		end
		
		local sceneId = DataCenter.heroLineupData:getFightLineupSceneId(DataCenter.mainLineData.curTemplateId);
		DataCenter.preLoadData:preShowScene("Lua_FightLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onSceneShow, nil, sceneId, 0);
	end
end

function Lua_MainLineDownPanel:onSceneShow(param)
	local data = { template_id = DataCenter.mainLineData.curTemplateId, monster_player_id = self.data.robot_id };
	Lua_WindowUtil.openWin("Lua_FightLineupWindow", Lua_WinParam.ACTION_OPEN, data);
end

function Lua_MainLineDownPanel:onFastFightClick(go)
	local openId = DataCenter.mainLineUtil.fast_open_id;
	if not DataCenter.funcOpenData:isOpened(openId, true) then
		return;
	end
	self.redPoint_fastFight:clickHandler();
	Lua_WindowUtil.openWin("Lua_FastFightWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_MainLineDownPanel:ckeckExploreState()
	if DataCenter.taskData.openState then
		if self.exploreBtn == nil then
			self.exploreBtn = UICreate.createUIAtlasImage(self.content, "common_altas_1", "xui_zjm_btn_001_n", 288, 280, 0, 0);
			self.exploreBtn:addClickFuntion(self, self.onExploreBtnClick);
		end
		self.exploreBtn:setEnable(true);
		if self.exploreRedDot == nil then
			self.exploreRedDot = Lua_RedPointIcon.new(self.content, Lua_RedPointList.ExploreTour);
			self.exploreRedDot:setLocation(310, 305, 0);
		end
		self.exploreRedDot:setEnable(true);
	else
		if self.exploreBtn ~= nil then
			self.exploreBtn:setEnable(false);
		end
		if self.exploreRedDot ~= nil then
			self.exploreRedDot:setEnable(false);
		end
	end
end

function Lua_MainLineDownPanel:onExploreBtnClick()
	Lua_WindowUtil.openWin("Lua_ExploreTourWindow", Lua_WinParam.ACTION_OPEN);
end