Lua_MainLineSpecialRewardWindow = class("Lua_MainLineSpecialRewardWindow", Lua_Window)
function Lua_MainLineSpecialRewardWindow:ctor()
	self:superCall("ctor")

	self.windowName = "Lua_MainLineSpecialRewardWindow"
	self.skinName = "MainLineSpecialRewardWindow_skin"
	self.showBlackMask = true
	self.isClickClose = true
end

function Lua_MainLineSpecialRewardWindow:buildShowItem()
	self:superCall("buildShowItem")
	self.itemArr = Array()
	self.btnReceive:addClickFuntion(self, self.onReceive)

	self.uiEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_zx_tgjl_03", "ui_zx_tgjl_03", 0, 0)
	
	self:addLuaEvent("MAINLINE_REWARD_RECEIVE_UPDATE", self, self.updateShowInfo)
	self:updateShowInfo()
end

function Lua_MainLineSpecialRewardWindow:dispose()
	if self.uiEff then
		self.uiEff:dispose()
		self.uiEff = nil
	end
	if self.itemArr then
		self.itemArr:dispose()
		self.itemArr:clear()
		self.itemArr = nil
	end
	self:superCall("dispose")
end

function Lua_MainLineSpecialRewardWindow:updateShowInfo()
	local item
	local list = DataCenter.mainLineUtil.specialReward
	local state
	local len = #list
	local bCompleted = false
	self.canReceive = false
	for i = 1, len do
		item = self.itemArr[i]
		if item == nil then
			item = Lua_MainLineSpecialRewardItem.new(self.content)
			self.itemArr:add(item)
		end
		item:setData(list[i], i, len)

		state = DataCenter.mainLineData:getCheckpointReceiveState(list[i])
		if i == len and state == 2 then
			bCompleted = true
		end
		if state == 1 then
			self.canReceive = true
		end
	end

	local space = 170
	local w = -(space * len) / 2 + space / 2
	for i = 1, len do
		item = self.itemArr[i]
		item:setLocation(((i - 1) % len) * space + w, -117, 0)
	end

	local checkpointId = DataCenter.mainLineData.checkpointId
	local config = Lua_MainLineCheckpointConfigData.getConfig(checkpointId)
	if DataCenter.mainLineData.checkpointState ~= 1 then
		config = Lua_MainLineCheckpointConfigData.getConfig(config.prev_game_level_id)
	end
	local number = config == nil and 0 or config.number
	local maxValue = 515
	local oneValue = maxValue / (len - 1)
	local value = 0
	if number > 0 then
		local index = 0
		for i = 1, len do
			temp = Lua_MainLineCheckpointConfigData.getConfig(list[i]).number
			if temp >= number then
				index = i
				break
			end
		end
		if index == 0 then
			value = maxValue
		elseif index > 1 then
			local prev = Lua_MainLineCheckpointConfigData.getConfig(list[index - 1]).number
			value = oneValue / (temp - prev)
			value = (number - prev) * value
			value = value + (index - 2) * oneValue
		else
			value = 15
		end
	end
	self.receiveBar:setMaxValue(maxValue)
	self.receiveBar:setValue(value)

	if bCompleted then
		self.btnReceive:setLangValue(307056)
	elseif self.canReceive then
		self.btnReceive:setLangValue(307018)
	else
		self.btnReceive:setLangValue(307052)
	end
end

function Lua_MainLineSpecialRewardWindow:onReceive(go)
	if self.canReceive then
		local arr = Array()
		local list = DataCenter.mainLineUtil.specialReward
		local state
		for i = 1, #list do
			state = DataCenter.mainLineData:getCheckpointReceiveState(list[i])
			if state == 1 then
				arr:add(list[i])
			end
		end
		Lua_ProxyManager.getProxy("Lua_MainLineProxy"):sReceiveReward(arr)
	else
		self:hide()
	end
end










Lua_MainLineSpecialRewardItem = class("Lua_MainLineSpecialRewardItem", Lua_DisplayObject)
function Lua_MainLineSpecialRewardItem:ctor(p)
	self:superCall("ctor", p, "MainLineSpecialRewardItem_skin")
end

function Lua_MainLineSpecialRewardItem:buildShowItem()
	self:superCall("buildShowItem")
	self.itemIcon = Lua_ItemIcon.new(self.content)
	self.itemIcon:setLocation(0, 130, 0)
	self.itemIcon:setCanClick(true)
end

function Lua_MainLineSpecialRewardItem:dispose()
	if self.uiEff then
		self.uiEff:dispose()
		self.uiEff = nil
	end
	if self.itemIcon then
		self.itemIcon:dispose()
		self.itemIcon = nil
	end
	self:superCall("dispose")
end

function Lua_MainLineSpecialRewardItem:setData(data, index, len)
	local config = Lua_MainLineCheckpointConfigData.getConfig(data)
	self.nameText.text = LanUtil.formateStr(307017, tostring(config.chapter_id), tostring(config.level))

	config = Lua_RewardConfigData.getConfigDataById(config.reward_id)
	self.itemIcon:setData(config.rewardsArr[1])

	local state = DataCenter.mainLineData:getCheckpointReceiveState(data)
	if state == 0 then
		self.stateIcon:setAltas("main_line_altas", "xui_zxtt_progress_11_b")
	else
		self.stateIcon:setAltas("main_line_altas", "xui_zxtt_progress_11_f")
	end
	self.itemIcon:setDrawMask(state == 2)
	self:showEff(state == 1)
	
	if index == len then
		self.itemIcon:setScale(1.1, 1.1, 1)
		if self.uiEff then
			self.uiEff:setScale(1.1, 1.1, 1)
		end
	else
		self.itemIcon:setScale(0.9, 0.9, 1)
		if self.uiEff then
			self.uiEff:setScale(0.9, 0.9, 1)
		end
	end
end

function Lua_MainLineSpecialRewardItem:showEff(bValue)
	if bValue then
		if self.uiEff == nil then
			self.uiEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_zx_tgjl_02", "ui_zx_tgjl_02", 0, 130)
		else
			self.uiEff:setEnable(true)
		end
	else
		if self.uiEff then
			self.uiEff:setEnable(false)
		end
	end
end