Lua_MainLineTopPanel = class("Lua_MainLineTopPanel", Lua_DisplayObject);
function Lua_MainLineTopPanel:ctor(p)
	self:superCall("ctor", p, "MainLineTopPanel_skin");
end

function Lua_MainLineTopPanel:buildShowItem()
	self:superCall("buildShowItem");

	self:addLuaEvent("MONEY_UPDATE", self, self.onMoneyUpdate);
	self:addLuaEvent("MAINLINE_REWARD_RECEIVE_UPDATE", self, self.updateRewardInfo);

	self.redPoint_dispatch = Lua_RedPointIcon.new(self.content, Lua_RedPointList.MainLine_Dispatch, Lua_RedPointList.MainLine_DispatchReward);
	self.redPoint_dispatch:setLocation(320, -90, 0);

	self.normalBar.typeValue = 3;
	self.normalBar.fillMethodValue = 4;
	self.normalBar.fillOrigin = 0;
	self.normalBar.fillAmount = 0;
	self.overflowBar.typeValue = 3;
	self.overflowBar.fillMethodValue = 4;
	self.overflowBar.fillOrigin = 0;
	self.overflowBar.fillAmount = 0;
	self.overflowBar:setEnable(false)

	self.checkTask:addClickFuntion(self, self.onCheckTask);
	self.checkReward:addClickFuntion(self, self.onCheckReward);
end

function Lua_MainLineTopPanel:dispose()
	if self.redPoint_dispatch ~= nil then
		self.redPoint_dispatch:dispose();
		self.redPoint_dispatch = nil;
	end
	if self.redPoint_reward ~= nil then
		self.redPoint_reward:dispose();
		self.redPoint_reward = nil;
	end
	if self.uiEff then
		self.uiEff:dispose()
		self.uiEff = nil
	end
	self:superCall("dispose");
end

function Lua_MainLineTopPanel:setData(data)
	self:updateTaskInfo();
	self:updateRewardInfo();
end

function Lua_MainLineTopPanel:onMoneyUpdate(dic)
	if dic == nil or dic[Lua_ResourcesDefine.INTELLIGENCE] == nil then
		return;
	end
	self:updateTaskInfo();
end

function Lua_MainLineTopPanel:updateTaskInfo()
	local maxValue = DataCenter.mainLineUtil.maxInfoValue;
	local value = DataCenter.moneyData:getMoney(Lua_ResourcesDefine.INTELLIGENCE);
	local overflowValue = DataCenter.mainLineData.task_temp_info
	if overflowValue > value - maxValue then
		overflowValue = value - maxValue
	end
	self.normalBar.fillAmount = value / maxValue
	if overflowValue > 0 then
		self.overflowBar:setEnable(true)
		-- local ringNum = Mathf.Ceil(overflowValue / maxValue)
		local ringValue = overflowValue - Mathf.Floor(overflowValue / maxValue) * maxValue
		self.overflowBar.fillAmount = ringValue / maxValue
	else
		self.overflowBar:setEnable(false)
	end
	self.intelligenceText.text = LanUtil.formateStr(10044, tostring(value), tostring(maxValue))
end

function Lua_MainLineTopPanel:updateRewardInfo()
	local state, des, reward_id = DataCenter.mainLineUtil:getRewardsInfo();
	self.rewardText.text = des;
	if reward_id == nil then
		self.checkReward:setEnable(false);
		self.rewardIcon:setEnable(false);
		if self.redPoint_reward ~= nil then
			self.redPoint_reward:setEnable(false);
		end
	else
		self.checkReward:setEnable(true);
		self.rewardIcon:setEnable(true);
		local config = Lua_RewardConfigData.getConfigDataById(reward_id);
		local atlas, sprite = config.rewardsArr[1]:getAvatarFromItemTable()
		self.rewardIcon:setAltas(atlas, sprite);
		self.rewardIcon:SetDimensions(112, 112);
		self.rewardIcon:setScale(0.7, 0.7, 1);

		if self.redPoint_reward == nil then
			self.redPoint_reward = Lua_RedPointIcon.new(self.content, Lua_RedPointList.MainLine_Reward);
			self.redPoint_reward:setLocation(320, -250, 0);
		end
		self.redPoint_reward:setEnable(true);
	end

	self:showEff(state)
end

function Lua_MainLineTopPanel:showEff(bValue)
	if bValue then
		if self.uiEff == nil then
			self.uiEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_zx_tgjl_01", "ui_zx_tgjl_01", 287, -279)
			self.uiEff.siblingIndex = 6
		else
			self.uiEff:setEnable(true)
		end
	else
		if self.uiEff then
			self.uiEff:setEnable(false)
		end
	end
end

function Lua_MainLineTopPanel:onCheckTask(go)
	local openId = DataCenter.mainLineUtil.dispatch_open_id;
	if not DataCenter.funcOpenData:isOpened(openId, true) then
		return;
	end

	self.redPoint_dispatch:clickHandler();
	Lua_WindowUtil.openWin("Lua_MainLineTaskWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_MainLineTopPanel:onCheckReward()
	if DataCenter.mainLineData:getSpecialRewardState() then
		Lua_WindowUtil.openWin("Lua_MainLineSpecialRewardWindow", Lua_WinParam.ACTION_OPEN);
	else
		Lua_WindowUtil.openWin("Lua_MainLineRewardWindow", Lua_WinParam.ACTION_OPEN);
	end
end