checkRequire("Lua_MainLineTopPanel");
checkRequire("Lua_OnLineEnterPanel");
checkRequire("Lua_HookIncomePanel");
checkRequire("Lua_MainLineDownPanel");
Lua_MainLineWindow = class("Lua_MainLineWindow", Lua_Window);
function Lua_MainLineWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.MAIN_WINDOW_LAYER;
	self.windowName = "Lua_MainLineWindow";
	-- self.skinName = "MainLineWindow_skin";
	self.isFullSizeWin = true;
	self.winSceneId = DataCenter.mainLineData.curSceneId;
end

function Lua_MainLineWindow:buildShowItem()
	self:superCall("buildShowItem");

	self:addLuaEvent("FUNCTION_OPEN", self, self.onFuncOpen);
	self:addLuaEvent("UPDATE_MAINLINE_INFO", self, self.updateShowInfo);
	self:addLuaEvent("MAINLINE_CHAPTER_SELECT", self, self.onChapterSelected);
	-- self:addLuaEvent("MAINLINE_CHAPTER_LIST_CLOSE", self, self.onDownMenuClick);
	self:addLuaEvent("SCENE_SHOW", self, self.onSceneShow);
	self:addLuaEvent("MAINLINE_CAM_ACT_CONPLETED", self, self.onCamActCompleted);

	-- self.bDropDownMenu = false;
	-- self.downMenuArrow:setRot(0, 0, self.bDropDownMenu and 0 or -180);
	-- self.downMenuBg:addClickFuntion(self, self.onDownMenuClick);

	self.bShowTopInfo = false;
	self.bShowDownInfo = false;
	self.bShowOnlineInfo = false;
	self.bShowHookInfo = false;
	self:updateShowInfo();
end

function Lua_MainLineWindow:dispose()
	self:endTimer();
	DataCenter.mainLineCamActController:stopCamAct(true);
	if self.topPanel ~= nil then
		self.topPanel:dispose();
		self.topPanel = nil;
	end
	if self.onlinePanel ~= nil then
		self.onlinePanel:dispose();
		self.onlinePanel = nil;
	end
	if self.hookPanel ~= nil then
		self.hookPanel:dispose();
		self.hookPanel = nil;
	end
	if self.downPanel ~= nil then
		self.downPanel:dispose();
		self.downPanel = nil;
	end
	if self.cameraEff then
		self.cameraEff:dispose()
		self.cameraEff = nil
	end
	if self.sceneEff then
		self.sceneEff:dispose()
		self.sceneEff = nil
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_MainLineWindow:onScreenResize()
	self:superCall("onScreenResize");
	self:showCamAction(self.selectChapterId);
	if self.bg then
		self.bg:SetDimensions(self.width, self.height)
	end
end

function Lua_MainLineWindow:resetActive(val)
	self:superCall("resetActive", val);
	if val then
		if self.selectChapterId ~= nil then
			self:onChapterSelected(self.selectChapterId);
		end
	else
		DataCenter.mainLineCamActController:stopCamAct();
		if self.cameraEff then
			self.cameraEff:setEnable(false)
		end
		if self.sceneEff then
			self.sceneEff:setEnable(false)
		end
	end
end

function Lua_MainLineWindow:onFuncOpen(openDic)
	if openDic == nil or openDic[10095] == nil then
		return;
	end
	self:createHookPanel();
end

function Lua_MainLineWindow:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		Lua_CommonUtil.addTimer("Lua_MainLineWindow", 0.1, self, self.onTimer);
	end
end

function Lua_MainLineWindow:endTimer()
	if self.bTimer == true then
		self.bTimer = false;
		Lua_CommonUtil.removeTimer(self, self.onTimer);
	end
end

function Lua_MainLineWindow:onTimer()
	if not self.bShowTopInfo then
		self.bShowTopInfo = true;
		if self.topPanel == nil then
			self.topPanel = Lua_MainLineTopPanel.new(self.content);
			self.topPanel:setRectAnchor(1);
		end
		self.topPanel:setData(self.data);
	elseif not self.bShowDownInfo then
		self.bShowDownInfo = true;
		if self.downPanel == nil then
			self.downPanel = Lua_MainLineDownPanel.new(self.content);
			self.downPanel:setRectAnchor(7);
		end
		self.downPanel:setData(self.data);
		self.downPanel:setBtnEnable(self.selectChapterId >= DataCenter.mainLineData.curChapterId);
	elseif not self.bShowOnlineInfo then
		self:createOnlineIcon();
	elseif not self.bShowHookInfo then
		self:createHookPanel();
	else
		self:endTimer();
	end
end

function Lua_MainLineWindow:createOnlineIcon()
	local data = DataCenter.onlineRewardData;
	if self.onlinePanel == nil and (data.receiveVo ~= nil or data.timeVo ~= nil) then
		self.onlinePanel = Lua_OnLineEnterPanel.new(self.content);
		self.onlinePanel:setRectAnchor(9);
	end
	self.bShowOnlineInfo = true;
end

function Lua_MainLineWindow:createHookPanel()
	if DataCenter.funcOpenData:isOpened(10095) and self.hookPanel == nil then
		self.hookPanel = Lua_HookIncomePanel.new(self.content);
		self.hookPanel:setSiblingIndex(1);
		self.hookPanel:setRectAnchor(7);
	end
	self.bShowHookInfo = true;
end

function Lua_MainLineWindow:updateShowInfo()
	local chapterId = DataCenter.mainLineData.curChapterId;
	self:onChapterSelected(chapterId);

	local checkpointId = DataCenter.mainLineData.checkpointId;
	self.data = Lua_MainLineCheckpointConfigData.getConfig(checkpointId);
	
	if self.topPanel then
		self.topPanel:setData(self.data);
	end
	if self.downPanel then
		self.downPanel:setData(self.data);
	end
end

function Lua_MainLineWindow:onChapterSelected(chapterId)
	local data = Lua_MainLineChapterConfigData.getConfig(chapterId);
	if self.winSceneId ~= data.scene_id then
		self:setWinSceneId(data.scene_id);
	end
	-- self.chapterNum.text = LanUtil.formateStr(307000, tostring(chapterId));
	-- self.chapterName.text = data.name;

	self:showEff(data)

	-- 镜头动画
	if self.selectChapterId ~= chapterId then
		if self.downPanel then
			self.downPanel:setBtnEnable(false);
		end
		if not Scene3DManager.instance:isShowingScene(self.winSceneId, 0) then
			self.selectChapterId = chapterId;
		else
			self:showCamAction(chapterId);
		end
	end
end

function Lua_MainLineWindow:onSceneShow(sceneId)
	if sceneId == self.winSceneId then
		local chapterId = self.selectChapterId;
		self.selectChapterId = nil;
		self:showCamAction(chapterId);
	end
end

function Lua_MainLineWindow:showCamAction(chapterId)
	if not Scene3DManager.instance:isShowingScene(self.winSceneId, 0) then
		return;
	end
	self:showSceneMask(false)

	local checkpointId;
	if chapterId == nil or chapterId == DataCenter.mainLineData.curChapterId then -- 当前篇章
		checkpointId = DataCenter.mainLineData.checkpointId;
	else
		checkpointId = chapterId * 10000 + 1;
	end

	DataCenter.mainLineData.sceneNodeEffect = true;
	DataCenter.mainLineData.sceneNodeTween = true;
	local vec = Lua_MainLineCheckpointConfigData.getConfig(checkpointId).actionPos;
	if self.selectChapterId == nil then -- 第一次进入
		DataCenter.mainLineCamActController:showAction(chapterId, nil, nil, vec, true); -- 高点移动到低点
	elseif self.selectChapterId == chapterId then -- 战斗结束
		DataCenter.mainLineData.sceneNodeTween = false;
		DataCenter.mainLineCamActController:showAction(chapterId, self.selectChapterId, vec, vec, true); -- 直接移动到低点
	else -- 切换篇章
		DataCenter.mainLineCamActController:showAction(chapterId, self.selectChapterId, nil, vec, false); -- 回到高点再移动到低点
	end
	self.selectChapterId = chapterId;
end

function Lua_MainLineWindow:onCamActCompleted()
	DataCenter.mainLineData.sceneNodeEffect = false;
	self:startTimer();
	if self.downPanel then
		self.downPanel:setBtnEnable(self.selectChapterId >= DataCenter.mainLineData.curChapterId);
	end
	self:showSceneMask(true)
end

-- function Lua_MainLineWindow:onDownMenuClick(go)
-- 	self.bDropDownMenu = not self.bDropDownMenu;
-- 	self:updateDownMenuState();
-- end

-- function Lua_MainLineWindow:updateDownMenuState()
-- 	self.downMenuArrow:setRot(0, 0, self.bDropDownMenu and 0 or -180);
-- 	if self.bDropDownMenu then
-- 		Lua_WindowUtil.openWin("Lua_MainLineChapterListWindow", Lua_WinParam.ACTION_OPEN, self.selectChapterId);
-- 	else
-- 		Lua_WindowUtil.openWin("Lua_MainLineChapterListWindow", Lua_WinParam.ACTION_CLOSE);
-- 	end
-- end

function Lua_MainLineWindow:showSceneMask(bValue)
	if bValue then
		if self.bg == nil then
			self.bg = UICreate.createUIAtlasImage(self.content, "main_line_altas", "ui_dsj_01", 0, 0, self.width, self.height)
			self.bg.siblingIndex = 0
		else
			self.bg:setEnable(true)
		end
	else
		if self.bg then
			self.bg:setEnable(false)
		end
	end
end

function Lua_MainLineWindow:showEff(data)
	if strIsNullOrEmpty(data.cameraEff) then
		if self.cameraEff then
			self.cameraEff:setEnable(false)
		end
	else
		if self.cameraEff == nil then
			self.cameraEff = ModelEffComponent(GlobalVar.mainCamera.transform.gameObject)
			self.cameraEff.layer = 0
		else
			self.cameraEff:setEnable(true)
		end
		self.cameraEff:setUrl(data.cameraEffUrl, data.cameraEff, data.cameraEff)
	end

	if strIsNullOrEmpty(data.sceneEff) then
		if self.sceneEff then
			self.sceneEff:setEnable(false)
		end
	else
		if self.sceneEff == nil then
			self.sceneEff = ModelEffComponent(self.winSceneId, 0)
			self.sceneEff.layer = 0
		else
			self.sceneEff:setEnable(true)
		end
		self.sceneEff:setUrl(data.sceneEffUrl, data.sceneEff, data.sceneEff)
	end
end