Lua_FastFightResultWindow = class("Lua_FastFightResultWindow", Lua_Window);
function Lua_FastFightResultWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_FastFightResultWindow";
	self.skinName = "FastFightResultWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_FastFightResultWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.expBar.typeValue = 3;
	self.expBar.fillMethodValue = 0;
	self.expBar.fillOrigin = 0;

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setLocation(-188, 95, 0);
	self.avatarItem:setScale(0.8, 0.8, 0.8);

	self.itemList = Lua_DragList.new(self.content, 625, 175, Lua_AxisDefine.Vertical);
	self.itemList:setLocation(0, -110, 0);
	self.itemList:setListCell(Lua_ItemIconCell, 125, 120, 5);
	self.itemList:setCellSpacing(0, 5);
	self.itemList.tweenId = 2003;
end

function Lua_FastFightResultWindow:dispose()
	self:endTimer();
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.rewardArr ~= nil then
		self.rewardArr:clear();
		self.rewardArr = nil;
	end
	self:superCall("dispose");
end

function Lua_FastFightResultWindow:showWin(param)
	self:superCall("showWin", param);
	if param == nil then
		self:hide();
		return;
	end

	local addExp = 0;
	if self.rewardArr == nil and param.reward then
		local reward;
		for i = 1, #param.reward do
			reward = param.reward[i]
			if reward.id == Lua_ResourcesDefine.ROLE_EXP then
				addExp = addExp + reward.amount;
			end
		end
		local tab = DataCenter.packData:getRewardDic(param.reward);
		self.rewardArr = DataCenter.packData:getRewardList(tab);
	end
	self.rewardArr:sortf(self, self.onRewardSort);

	self.itemList:setArrayData(self.rewardArr);
	self:setRoleInfo(param.level, param.exp, addExp);

	local offline_time = DataCenter.mainLineUtil.one_hook_earnings_time * 60;
	self:setHookTime(offline_time);
end

function Lua_FastFightResultWindow:onRewardSort(a, b)
	a = DataCenter.mainLineUtil:getRewardSortValue(a);
	b = DataCenter.mainLineUtil:getRewardSortValue(b);
	if a < b then
		return false;
	end
	return true;
end

function Lua_FastFightResultWindow:setRoleInfo(level, exp, addExp)
	local roleData = DataCenter.roleData;
	local avatarId = roleData:getOwnDressUpId(Lua_DressUpDefine.MAINTYPE_HEAD);
	self.avatarItem:setRoleAvatar(avatarId);

	self.lvText.text = LanUtil.formateStr(10041, tostring(level));
	if roleData:checkMaxLv(level) == true then
		self.expBar:setMaxValue(1);
		self.expBar:setValue(1);
		self.expBar:setLangValue(307049);
	else
		self.level = level;
		self.exp = exp;
		self.addExp = addExp;
		self.addExpStep = self.addExp / 1.5;
		self.maxExp = DataCenter.roleUtil:getRoleVoByLv(level).exp;
		
		self.expBar:setMaxValue(self.maxExp);
		self.expBar:setValue(self.exp);
		self.expBar:setText(self.exp.."/"..self.maxExp);

		if self.addExp > 0 then
			self.startTime = getTime();
			self:startTimer();
		end
	end
end

function Lua_FastFightResultWindow:setHookTime(time)
	self.timeText.text = LanUtil.formateStr(307035, Lua_TimeTransform.transSeconds6(time));
end

function Lua_FastFightResultWindow:startTimer()
	if self.bTiming ~= true then
		self.bTiming = true;
		self:addTimer("Lua_FastFightResultWindow", 0.01, self, self.onTimer, nil, -1);
	end
end

function Lua_FastFightResultWindow:endTimer()
	if self.bTiming == true then
		self.bTiming = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_FastFightResultWindow:onTimer()
	local t = getTime();
	local deltaTime = t - self.startTime;
	self.startTime = t;
	local bBarEnd = self:showBarProgress(deltaTime);
	if bBarEnd == true then
		self:endTimer();
	end
end

function Lua_FastFightResultWindow:showBarProgress(deltaTime)
	if self.addExp <= 0 then
		return true;
	end

	local num = self.addExpStep * deltaTime;
	self.addExp = self.addExp - num;
	if self.addExp <= 0 then
		num = num + self.addExp;
	end
	self.exp = self.exp + num;

	self.maxExp = DataCenter.roleUtil:getRoleVoByLv(self.level).exp;
	if self.maxExp <= self.exp then
		self.exp = self.exp - self.maxExp;
		self.level = self.level + 1;
		self.maxExp = DataCenter.roleUtil:getRoleVoByLv(self.level).exp;
	end

	if self.level >= Lua_CommonUtil.getCommonConfig("role_max_level", 1) then
		self.expBar:setMaxValue(1);
		self.expBar:setValue(1);
		self.expBar:setLangValue(307049);
	else
		num = string.format("%.0f", self.exp);
		self.expBar:setMaxValue(self.maxExp);
		self.expBar:setText(num.."/"..self.maxExp);
		self.expBar:setPercent(self.exp / self.maxExp);
	end

	self.lvText.text = LanUtil.formateStr(10041, tostring(self.level));
	return false;
end