Lua_MainLineTaskDetailsWindow = class("Lua_MainLineTaskDetailsWindow", Lua_Window)
function Lua_MainLineTaskDetailsWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_MainLineTaskDetailsWindow";
	self.skinName = "MainLineTaskDetailsWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_MainLineTaskDetailsWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.selectedList = Array()
	self:addLuaEvent("SELECT_MAINLINE_TASK_HERO", self, self.updateHeroSelect);

	self.rItem = Lua_ItemIconList.new(self.content);
	self.rItem:setLocation(0, 194.5, 0);
	self.rItem.canClick = true;
	self.rItem.scaleVal = 0.84;

	self.heroList = Lua_DragList.new(self.content, 605, 185, Lua_AxisDefine.Vertical);
	self.heroList:setLocation(0, -192, 0);
	self.heroList.customParam = self.selectedList;
	self.heroList.tweenId = 2003;
	self.heroList:setListCell(Lua_MainLineHeroSelectItem, 105, 105, 5);
	self.heroList:setCellSpacing(20, 15);

	self.campSiftPanel = Lua_CampSiftPanel.new(self.content);
    self.campSiftPanel:setLocation(-32, -336, 0);
    self.campSiftPanel:setSiftItem(70, "726763", 28);
    self.campSiftPanel:setArrayData(DataCenter.heroUtil.siftAllInfo);
    self.campSiftPanel:setCallBack(self, self.onCampSelected);
    
	self.btnDispatchOne:addClickFuntion(self, self.onDispatchOneKey);
	self.btnDispatch:addClickFuntion(self, self.onDispatch);
end

function Lua_MainLineTaskDetailsWindow:dispose()
	if self.condArr then
		self.condArr:clear();
		self.condArr = nil;
	end
	if self.sendList then
		self.sendList:dispose();
		self.sendList:clear();
		self.sendList = nil;
	end
	if self.sendArr then
		self.sendArr:clear();
		self.sendArr = nil;
	end
	if self.heroList then
		self.heroList:dispose();
		self.heroList = nil;
	end
	if self.campSiftPanel then
		self.campSiftPanel:dispose();
		self.campSiftPanel = nil;
	end
	if self.heroArr then
		self.heroArr:clear();
		self.heroArr = nil;
	end
	if self.selectedList then
		self.selectedList:clear()
		self.selectedList = nil
	end
	self:superCall("dispose");
end

function Lua_MainLineTaskDetailsWindow:showWin(param)
	self:superCall("showWin", param);

	self.desText.text = param.des;
	self.rItem:setArrayData(param.reward);
	self:updateCondInfo();
	self:updateSendInfo();
	self.campSiftPanel:setSelected(Lua_HeroUtil.All_TYPE, true);
end

function Lua_MainLineTaskDetailsWindow:updateCondInfo()
	local arr = self.showData.condArr;
	if self.condArr == nil then
		self.condArr = Array();
		local item;
		for i = 1, arr:getSize() do
			item = Lua_MainLineTaskCondItem.new(self.content);
			item:setLocation(8 + (i - 1) * 65, 90, 0);
			item:setData(arr[i]);
			self.condArr:add(item);
		end
	else
		local bSatisfy;
		for i = 1, arr:getSize() do
			bSatisfy = DataCenter.mainLineData:checkCondIsSatisfy(self.selectedList, arr[i]);
			self.condArr[i]:setSatisfy(bSatisfy);
		end
	end
end

function Lua_MainLineTaskDetailsWindow:updateSendInfo()
	local len = self.showData.hero_num;
	if self.sendArr == nil then
		self.sendArr = Array();
		for i = 1, len do
			self.sendArr:add(0);
		end
	else
		for i = 1, len do
			self.sendArr[i] = 0;
		end

		for i = 1, self.selectedList:getSize() do
			self.sendArr[i] = self.selectedList[i];
		end
	end

	if self.sendList == nil then
		self.sendList = Array();
	end
	local num = self.sendList:getSize();
	local maxLen = len > num and len or num;
	local item;
	for i = 1, maxLen do
		item = self.sendList[i];
		if i > len then
			if item then
				item:setEnable(false)
			end
		else
			if item == nil then
				item = Lua_MainLineHeroSendItem.new(self.content)
				self.sendList:add(item)
			else
				item:setEnable(true)
			end
			item:setData(self.sendArr[i])
		end
	end

	local space = 112
	local w = -(space * len) / 2 + space / 2
	local posX
	for i = 1, len do
		item = self.sendList[i]
		posX = ((i - 1) % len) * space + w
		item:setLocation(posX, 0, 0)
	end
end

function Lua_MainLineTaskDetailsWindow:onCampSelected(campType)
	if self.showData == nil or self.selectedCamp == campType then
		return;
	end
	self.selectedCamp = campType;

	self.heroArr = DataCenter.mainLineData:getTaskHeroArr(campType, self.showData.hero_cond);
	self:updateHeroList(true);
end

function Lua_MainLineTaskDetailsWindow:updateHeroList(bMoveToFirst)
	self.heroList:setArrayData(self.heroArr);
	if bMoveToFirst == true then
		self.heroList:moveToIndex(1, true);
	end
end

function Lua_MainLineTaskDetailsWindow:updateHeroSelect(uniqueId)
	if self.sendArr == nil then
		return;
	end

	local len = self.sendArr:getSize();
	local bSelected, selectedNum = self:getHeroIsSelected(uniqueId);
	if bSelected then
		selectedNum = self:setHeroIsSelected(uniqueId, nil);
	elseif selectedNum < len then
		self:setHeroIsSelected(uniqueId, 1);
	end
	self:updateHeroList();
	
	if selectedNum >= len then
		OperateAlert.showLangValue(307038);
		return;
	end

	self:updateCondInfo();
	self:updateSendInfo();
end

function Lua_MainLineTaskDetailsWindow:setHeroIsSelected(uniqueId, state)
	if state == 1 then
		self.selectedList:add(uniqueId)
	else
		self.selectedList:removeItem(uniqueId)
	end
	return self.selectedList:getSize()
end

function Lua_MainLineTaskDetailsWindow:getHeroIsSelected(uniqueId)
	local len = self.selectedList:getSize();
	if self.selectedList:indexOf(uniqueId) == -1 then
		return false, len;
	end
	return true, len;
end

function Lua_MainLineTaskDetailsWindow:onDispatchOneKey(go)
	if self.showData == nil or self.sendArr == nil then
		return;
	end

	self.selectedList:clear();
	local heroArr;
	for i = 1, self.sendArr:getSize() do
		heroArr = self:getHeroArrByOneKey();
		if heroArr:getSize() > 0 then
			self:setHeroIsSelected(heroArr[1].unique_id, 1);
			self.sendArr[i] = heroArr[1].unique_id;
		end
	end
	heroArr:clear();
	heroArr = nil;

	self:updateHeroList();
	self:updateCondInfo();
	self:updateSendInfo();
end

function Lua_MainLineTaskDetailsWindow:getHeroArrByOneKey()
	local uidArr = DataCenter.heroData.allHeroUidArr;
	local arr = Array();
	local vo;
	for i = 1, uidArr:getSize() do
		vo = DataCenter.heroData:getItemByUniqueId(uidArr[i]);
		if not vo.send_info_state and not self:getHeroIsSelected(vo.unique_id) and self:getCondEnoughNum(vo) > 0 then
			arr:add(vo);
		end
	end
	arr:sortf(self, self.onOneKeySortFun);
	return arr;
end

function Lua_MainLineTaskDetailsWindow:onOneKeySortFun(a, b)
	local _a = self:getCondEnoughNum(a);
	local _b = self:getCondEnoughNum(b);
	-- print("0", a.name, a.star, b.name, b.star);
	if _a < _b then
		return false;
	elseif _a == _b then
		if a.star > b.star then
			-- print("1", a.name, a.star, b.name, b.star);
			return false;
		elseif a.star == b.star then
			-- print("2", a.name, a.star, b.name, b.star);
			if a.id > b.id then
				return false;
			end
		end
	end
	return true;
end

function Lua_MainLineTaskDetailsWindow:getCondEnoughNum(vo)
	local num = 0;
	local arr = self.showData.condArr;
	for i = 1, arr:getSize() do
		if not DataCenter.mainLineData:checkCondIsSatisfy(self.selectedList, arr[i]) then
			if arr[i].condType == 1 then
				if vo.quality >= arr[i].condValue[1] and vo.quality_star >= arr[i].condValue[2] then
					num = num + 1;
				end
			elseif arr[i].condType == 2 then
				if vo.campType == arr[i].condValue then
					num = num + 1;
				end
			end
		end
	end
	return num;
end

function Lua_MainLineTaskDetailsWindow:onDispatch(go)
	if self.showData == nil or self.condArr == nil or self.sendArr == nil then
		return;
	end

	for i = 1, self.condArr:getSize() do
		if not self.condArr[i].bSatisfy then
			OperateAlert.showLangValue(307039);
			return;
		end
	end

	local costId = DataCenter.packData:checkConsumeEnough(self.showData.cost);
	if costId == nil then
		Lua_ProxyManager.getProxy("Lua_MainLineProxy"):sTaskSend(self.showData.uid, self.sendArr);
	else
		DataCenter.packUtil:openPathWindow(self.showData.cost.id, false);
	end
end



















Lua_MainLineTaskCondItem = class("Lua_MainLineTaskCondItem", Lua_DisplayObject)
function Lua_MainLineTaskCondItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_MainLineTaskCondItem:buildShowItem()
	self:superCall("buildShowItem");
	self.icon = UICreate.createUIAtlasImage(self.content, nil, nil, 0, 0, 0, 0)
	self.icon:setScale(0.72, 0.72, 1)
	self.starArr = Array();
	self.bSatisfy = false;
end

function Lua_MainLineTaskCondItem:dispose()
	if self.starArr then
		self.starArr:dispose()
		self.starArr:clear()
		self.starArr = nil
	end
	self:superCall("dispose");
end

function Lua_MainLineTaskCondItem:setData(data)
	if data.condType == 1 then
		self.icon:setAltas("common_altas_4", "xui_common_attribute_"..(35 + data.condValue[1]));
		self:showStar(data.condValue[2])
	else
		self.icon:setAltas("common_altas_2", "xui_common_attribute_"..(16 + data.condValue).."_n");
		self:showStar(0)
	end
	self:setSatisfy(self.bSatisfy);
end

function Lua_MainLineTaskCondItem:showStar(dataLen)
	dataLen = dataLen or 0
	local len = self.starArr:getSize()
	local maxLen = dataLen > len and dataLen or len
	local star
	for i = 1, maxLen do
		star = self.starArr[i]
		if i > dataLen then
			if star then
				star:setEnable(false)
			end
		else
			if star == nil then
				star = UICreate.createUIAtlasImage(self.content, "common_altas_4", "xui_common_label_15", 0, 0, 0, 0)
				star:setScale(0.4, 0.4, 1)
				self.starArr:add(star)
			else
				star:setEnable(true)
			end
		end
	end

	if dataLen > 0 then
		local space = 5
		local w = -(space * dataLen) / 2 + space / 2
		local posX
		for i = 1, dataLen do
			star = self.starArr[i]
			posX = ((i - 1) % dataLen) * space + w
			star:setLocation(posX, -18, 0)
		end
	end
end

function Lua_MainLineTaskCondItem:setSatisfy(bSatisfy)
	self.bSatisfy = bSatisfy;
	self.icon:setGray(not bSatisfy);
end





















Lua_MainLineHeroSendItem = class("Lua_MainLineHeroSendItem", Lua_DisplayObject)
function Lua_MainLineHeroSendItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_MainLineHeroSendItem:buildShowItem()
	self:superCall("buildShowItem");

	self.heroItem = Lua_ItemIcon.new(self.content);
	self.heroItem:setScale(0.74, 0.74, 1);
	self.heroItem:setClick(self, self.onPressClick)

	self.addIcon = UICreate.createUIAtlasImage(self.content, "main_line_altas", "xui_zxtt_button_5_n", 0, 0, 0, 0);
end

function Lua_MainLineHeroSendItem:dispose()
	if self.heroItem then
		self.heroItem:dispose();
		self.heroItem = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_MainLineHeroSendItem:setData(data)
	if data == nil then
		return;
	end

	self.data = DataCenter.heroData:getItemByUniqueId(data);
	self.heroItem:setData(self.data);
	self.addIcon:setEnable(data == 0);
end

function Lua_MainLineHeroSendItem:onPressClick()
	if self.data == nil then
		return;
	end
	Lua_MsgUtil.callFunc("SELECT_MAINLINE_TASK_HERO", self.data.unique_id);
end





















Lua_MainLineHeroSelectItem = class("Lua_MainLineHeroSelectItem", Lua_ListCell)
function Lua_MainLineHeroSelectItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_MainLineHeroSelectItem:buildShowItem()
	self:superCall("buildShowItem");

	self.heroItem = Lua_ItemIcon.new(self.content);
	self.heroItem:setScale(0.84, 0.84, 1);
	self.heroItem:setCanClick(false);
end

function Lua_MainLineHeroSelectItem:dispose()
	if self.heroItem then
		self.heroItem:dispose();
		self.heroItem = nil;
	end
	self.maskIcon = nil;
	self.tickIcon = nil;
	self.selectedList = nil;
	self.data = nil;
	self:superCall("dispose");
end

function Lua_MainLineHeroSelectItem:setCustomParam(customParam)
	self.selectedList = customParam
end

function Lua_MainLineHeroSelectItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end
	
	self.heroItem:setData(data);
	self:setMask(data.send_info_state);
	if self.selectedList == nil or self.selectedList:indexOf(data.unique_id) == -1 then
		self:setSelected(false);
	else
		self:setSelected(true);
	end
end

function Lua_MainLineHeroSelectItem:setMask(bMask)
	if bMask then
		if self.maskIcon == nil then
			self.maskIcon = UICreate.createUIAtlasImage(self.content, "common_altas_1", "ui_common_window_015", 0, 0, 0, 0);
		end
		self.maskIcon:setEnable(true);
	else
		if self.maskIcon then
			self.maskIcon:setEnable(false);
		end
	end
end

function Lua_MainLineHeroSelectItem:setSelected(bSelected)
	if bSelected then
		if self.tickIcon == nil then
			self.tickIcon = UICreate.createUIAtlasImage(self.content, "common_altas_1", "ui_common_window_014", 0, 0, 0, 0);
		end
		self.tickIcon:setEnable(true);
	else
		if self.tickIcon then
			self.tickIcon:setEnable(false);
		end
	end
end

function Lua_MainLineHeroSelectItem:onPressClick()
	if self.data == nil then
		return;
	end

	if self.data.send_info_state then
		OperateAlert.showLangValue(307040);
		return;
	end
	Lua_MsgUtil.callFunc("SELECT_MAINLINE_TASK_HERO", self.data.unique_id);
end