Lua_MainLineTaskWindow = class("Lua_MainLineTaskWindow", Lua_Window)
function Lua_MainLineTaskWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_MainLineTaskWindow";
	self.skinName = "MainLineTaskWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_MainLineTaskWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.intelligenceBg:setEnable(false)
	self.intelligenceText.text = nil
	self.normalBar.typeValue = 3
	self.normalBar.fillMethodValue = 0
	self.normalBar.fillOrigin = 0
	self.normalBar.fillAmount = 0
	self.overflowBar.typeValue = 3
	self.overflowBar.fillMethodValue = 0
	self.overflowBar.fillOrigin = 0
	self.overflowBar.fillAmount = 0
	self.overflowBar:setEnable(false)
	
	self.costIcon:addClickFuntion(self, self.onCheckCost);
	self.btnRefresh:addClickFuntion(self, self.onRefreshBtnClick);
	self.btnReceive:addClickFuntion(self, self.onReceiveBtnClick);

	self:addLuaEvent("MONEY_UPDATE", self, self.onMoneyUpdate);
	self:addLuaEvent("UPDATE_MAINLINE_TASK", self, self.updateShowInfo);
	self:getTaskInfo()
end

function Lua_MainLineTaskWindow:dispose()
	self:endTimer()
	Lua_CommonUtil.removeTimer(self, self.updateIntelligence)
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.costIconItem ~= nil then
		self.costIconItem:dispose();
		self.costIconItem = nil;
	end
	self:superCall("dispose");
end

function Lua_MainLineTaskWindow:getTaskInfo()
	Lua_ProxyManager.getProxy("Lua_MainLineProxy"):sTaskInfo();
end

function Lua_MainLineTaskWindow:onMoneyUpdate(dic)
	if dic == nil or dic[Lua_ResourcesData.INTELLIGENCE] == nil then
		return;
	end
	self:updateIntelligence();
end

function Lua_MainLineTaskWindow:updateShowInfo()
	local arr = DataCenter.mainLineData.taskArr;
	if arr == nil or arr:getSize() <= 0 then
		self:showNone(true);
		if self.itemList then
			self.itemList:setEnable(false);
		end
	else
		self:showNone(false);
		if self.itemList == nil then
			self.itemList = Lua_DragList.new(self.content, 627, 630, Lua_AxisDefine.Vertical);
			self.itemList:setLocation(0, -102.5, 0);
			self.itemList.tweenId = 2008;
			self.itemList:setListCell(Lua_MainLineTaskItem, 627, 143, 1);
			self.itemList:setCellSpacing(0, 5);
		end
		self.itemList:setEnable(true);
		self.itemList:setArrayData(arr);
		self.itemList:moveToIndex(1, true);
	end

	self:updateIntelligence();
	self:updateRefreshTimes();
	self:updateCost();
end

function Lua_MainLineTaskWindow:showNone(bValue)
	if bValue then
		if self.noneIcon == nil then
			self.noneIcon = UICreate.createUIAtlasImage(self.content, "common_altas_3", "xui_common_widget_012", 0, -95, 0, 0);
			self.noneText = UICreate.createLabel(self.content, nil, 0, -126.5, 100, 40, 40);
			self.noneText.pivotValue = 4;
			self.noneText.fontName = Lua_MyUISettings.huakangFontName;
			self.noneText.alignmentValue = 4;
			self.noneText.horizontalOverflowValue = 1;
			self.noneText.colorStr = Lua_ColorDefine.transColorStr("938680");
			self.noneText:setLangValue(307020);
		end
		self.noneIcon:setEnable(true);
		self.noneText:setEnable(true);
	else
		if self.noneIcon then
			self.noneIcon:setEnable(false);
			self.noneText:setEnable(false);
		end
	end
end

function Lua_MainLineTaskWindow:updateIntelligence()
	self:endTimer()
	Lua_CommonUtil.removeTimer(self, self.updateIntelligence)

	local maxValue = DataCenter.mainLineUtil.maxInfoValue
	local value = DataCenter.moneyData:getMoney(Lua_ResourcesDefine.INTELLIGENCE)
	local overflowValue = DataCenter.mainLineData.task_temp_info
	if overflowValue > value - maxValue then
		overflowValue = value - maxValue
	end
	self.normalBar.fillAmount = value / maxValue
	if overflowValue > 0 then
		self.overflowBar:setEnable(true)
		-- local ringNum = Mathf.Ceil(overflowValue / maxValue)
		-- if ringNum == 1 then
		-- 	self.normalBar:setAltas("main_line_altas", "xui_zxtt_progress_7_f")
		-- 	self.overflowBar:setAltas("main_line_altas", "xui_zxtt_progress_8_f")
		-- elseif ringNum == 2 then
		-- 	self.normalBar:setAltas("main_line_altas", "ui_zxtt_progress_4_f")
		-- 	self.overflowBar:setAltas("main_line_altas", "xui_zxtt_progress_8_f")
		-- end
		local ringValue = overflowValue - Mathf.Floor(overflowValue / maxValue) * maxValue
		self.overflowBar.fillAmount = ringValue / maxValue

		self.intelligenceBg:setEnable(true)
		local sec = DataCenter.mainLineData.task_temp_tick - DataCenter.roleData.serverTime
		local hour = Mathf.Modf(sec / 3600)
		if hour < 1 then
			if sec > 0 then
				if sec < 60 then
					self:startTimer()
					self.intelligenceText.text = LanUtil.formateStr(307053, tostring(sec), LanUtil.getValue(26))
				else
					Lua_CommonUtil.delayCall(60, self, self.updateIntelligence)
					self.intelligenceText.text = LanUtil.formateStr(307053, tostring(Mathf.Modf(sec / 60)), LanUtil.getValue(45))
				end
			else
				self.intelligenceText.text = nil
			end
		else
			Lua_CommonUtil.delayCall(3600, self, self.updateIntelligence)
			self.intelligenceText.text = LanUtil.formateStr(307053, tostring(hour), LanUtil.getValue(44))
		end
	else
		self.overflowBar:setEnable(false)
		self.intelligenceBg:setEnable(false)
		self.intelligenceText.text = nil
	end
	self.intelligenceCount.text = LanUtil.formateStr(10044, tostring(value), tostring(maxValue))
end

function Lua_MainLineTaskWindow:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_MainLineTaskWindow", 1, self, self.onTimer, nil, -1);
	end
end

function Lua_MainLineTaskWindow:endTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_MainLineTaskWindow:onTimer()
	local sec = DataCenter.mainLineData.task_temp_tick - DataCenter.roleData.serverTime
	if sec > 0 then
		self.intelligenceText.text = LanUtil.formateStr(307053, tostring(sec), LanUtil.getValue(26))
	else
		self:endTimer()
		self:getTaskInfo()
		self.intelligenceText.text = nil
	end
end

function Lua_MainLineTaskWindow:updateRefreshTimes()
	if DataCenter.mainLineData.task_free_times > 0 then
		self.btnRefresh:setLangValue(307021);
		if self.costIconItem ~= nil then
			self.costIconItem:setEnable(false);
		end
	else
		self.refreshCost = DataCenter.mainLineUtil.refresh_info_item;
		local haveCount = DataCenter.packData:getItemCountById(self.refreshCost[1]);
		if haveCount <= 0 then
			self.refreshCost = DataCenter.mainLineUtil.refresh_info_gold;
		end

		self.btnRefresh.label = nil;
		if self.costIconItem == nil then
			self.costIconItem = Lua_ConsumeIconItem.new(self.content);
			self.costIconItem:setLocation(-7, -473, 0);
			self.costIconItem:setStyle(Lua_MyUISettings.huakangFontName, 30);
		end
		self.costIconItem:setEnable(true);
		self.costIconItem:setData(self.refreshCost, nil, LanUtil.formateStr(307022, tostring(self.refreshCost[2])));
	end
end

function Lua_MainLineTaskWindow:updateCost()
	self.costCount.text = DataCenter.packData:getItemCountById(204010001);
end

function Lua_MainLineTaskWindow:onCheckCost(go)
	DataCenter.packUtil:openPathWindow(204010001, false);
end

function Lua_MainLineTaskWindow:onRefreshBtnClick(go)
	self:checkQuality();
end

function Lua_MainLineTaskWindow:checkQuality()
	if DataCenter.mainLineData.bTaskHighQuality then
		local tipsData = { des = LanUtil.getValue(307026), btnType = 1, owner = self, sureFun = self.checkFree };
		Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
	else
		self:checkFree();
	end
end

function Lua_MainLineTaskWindow:checkFree()
	if DataCenter.mainLineData.task_free_times > 0 then
		Lua_ProxyManager.getProxy("Lua_MainLineProxy"):sTaskRefresh();
	else
		self:checkConsume();
	end
end

function Lua_MainLineTaskWindow:checkConsume()
	if self.refreshCost[1] == Lua_ResourcesDefine.DIAMOND then
		if DataCenter.neverTipData:getNeverValue(Lua_NeverTipDefine.MAINLINE_TASK_REFRESH) then
			self:onConfirmRefresh();
		else
			local str = spliceIconStrById(self.refreshCost[1]);
			local tipsData = { des = LanUtil.formateStr(307027, str, tostring(self.refreshCost[2])), 
			btnType = 1, neverTip = Lua_NeverTipDefine.MAINLINE_TASK_REFRESH, owner = self, sureFun = self.onConfirmRefresh };
			Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
		end
	else
		self:onConfirmRefresh();
	end
end

function Lua_MainLineTaskWindow:onConfirmRefresh()
	local costId = DataCenter.packData:checkConsumeEnough(self.refreshCost);
	if costId == nil then
		Lua_ProxyManager.getProxy("Lua_MainLineProxy"):sTaskRefresh();
	else
		DataCenter.packUtil:openPathWindow(costId, false);
	end
end

function Lua_MainLineTaskWindow:onReceiveBtnClick(go)
	if not DataCenter.mainLineData.bTaskCanReceive then
		OperateAlert.showLangValue(307037);
		return;
	end
	Lua_ProxyManager.getProxy("Lua_MainLineProxy"):sTaskRewardReceive(0);
end




















Lua_MainLineTaskItem = class("Lua_MainLineTaskItem", Lua_ListCell)
function Lua_MainLineTaskItem:ctor(p)
	self:superCall("ctor", p, "MainLineTaskItem_skin");
end

function Lua_MainLineTaskItem:buildShowItem()
	self:superCall("buildShowItem");

	self.rItem = Lua_ItemIconList.new(self.content);
	self.rItem:setLocation(50, 0, 0);
	self.rItem.pivot = 1;
	self.rItem.scaleVal = 0.7;

	self.btnFunc:addClickFuntion(self, self.onFuncBtnClick);
end

function Lua_MainLineTaskItem:dispose()
	self:endTimer();
	if self.rItem ~= nil then
		self.rItem:dispose();
		self.rItem = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_MainLineTaskItem:setData(data)
	self.data = data;
	self:updateData();
end

function Lua_MainLineTaskItem:updateData()
	self:endTimer();
	if self.data == nil then
		return;
	end

	self.colorBg:setAltas("main_line_altas", "xui_zxtt_window_"..self.data.color + 1);
	if self.data.color == 1 then
		self.nameText.text = Lua_ColorDefine.getColorStr("5D452E", self.data.name);
	else
		self.nameText.text = Lua_ColorDefine.getColorStr(Lua_ColorDefine.getItemColorStr(self.data.color), self.data.name);
	end
	self.rItem:setArrayData(self.data.reward);

	self.costCount.colorStr = Lua_ColorDefine.transColor("776554");
	local costVo = self.data.costVo;
	if costVo == nil then
		self.costObject:SetActive(false);
	else
		self.costObject:SetActive(true);
		self.costIcon:setAltas(costVo.iconAtlas, costVo.iconSprite);
		self.costIcon:SetDimensions(costVo.iconWidth, costVo.iconHeight);
		self.costCount.text = costVo.count;
	end

	if self.data.state == 0 then -- 未派遣
		if DataCenter.packData:getItemCountById(costVo.id) < costVo.count then
			self.costCount.colorStr = Lua_ColorDefine.transColor("ED4C30");
		end
		self.timeText.text = LanUtil.formateStr(307023, Lua_TimeTransform.transSeconds23(self.data.time));
		self.timeBar:setEnable(false);
		self.btnFunc:setLocation(211, -19, 0);
		self.btnFunc:setStyle(3);
		self.btnFunc:setLangValue(307024);
		self:showRedDot(false);
	elseif self.data.state == 1 then -- 派遣中
		self.timeText.text = nil;
		self.timeBar:setEnable(true);
		self.timeBar:setMaxValue(self.data.time);
		self:startTimer();
		self:onTimer();
		self.btnFunc:setLocation(211, -19, 0);
		self.btnFunc:setStyle(1);
		self.btnFunc:setLangValue(307025);
		self:showRedDot(false);
	elseif self.data.state == 2 then -- 派遣完成可领取
		self.timeText.text = nil;
		self.timeBar:setEnable(true);
		self.timeBar:setMaxValue(1);
		self.timeBar:setValue(1);
		self.timeBar:setText(Lua_TimeTransform.transSeconds6(0));
		self.btnFunc:setLocation(211, 0, 0);
		self.btnFunc:setStyle(1);
		self.btnFunc:setLangValue(307018);
		self:showRedDot(true);
	end
end

function Lua_MainLineTaskItem:startTimer()
	if self.bTiming ~= true then
		self.bTiming = true;
		self:addTimer("Lua_MainLineTaskItem", 1, self, self.onTimer, nil, -1);
	end
end

function Lua_MainLineTaskItem:endTimer()
	if self.bTiming == true then
		self.bTiming = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_MainLineTaskItem:onTimer()
	if self.data == nil or self.data.state ~= 1 then
		return;
	end

	local time = self.data.leftTime;
	if time < 0 then
		time = 0;
	end
	self.timeBar:setText(Lua_TimeTransform.transSeconds6(time));
	
	time = self.data.time - self.data.leftTime;
	if time > self.data.time then
		time = self.data.time;
	end
	self.timeBar:setValue(time);
end

function Lua_MainLineTaskItem:showRedDot(bShow)
	if bShow == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:setLocation(280, 15, 0);
			self.redPoint:createRedPointEff();
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_MainLineTaskItem:onPressClick()
	self.rItem:onBoundClick();
end

function Lua_MainLineTaskItem:onFuncBtnClick(go)
	if self.data == nil then
		return;
	end

	if self.data.state == 0 then
		local costId = DataCenter.packData:checkConsumeEnough(self.data.costVo);
		if costId ~= nil then
			DataCenter.packUtil:openPathWindow(self.data.costVo, true);
			return
		end
		Lua_WindowUtil.openWin("Lua_MainLineTaskDetailsWindow", Lua_WinParam.ACTION_OPEN, self.data);
	elseif self.data.state == 1 then
		local tvo = self.data.costVo;
		local count = tonumber(self.costCount.text);
		if tvo and count == tvo.count then
			local str = spliceIconStr(tvo.iconAtlas, tvo.iconSprite, tvo.iconWidth, tvo.iconHeight);
			local tipsData = { des = LanUtil.formateStr(307028, str, tostring(tvo.count)), 
			btnType = 1, owner = self, sureFun = self.onTaskSpeedUp };
			Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
		else
			self:updateData();
			OperateAlert.showLangValue(307048);
		end
	elseif self.data.state == 2 then
		Lua_ProxyManager.getProxy("Lua_MainLineProxy"):sTaskRewardReceive(self.data.uid);
	end
end

function Lua_MainLineTaskItem:onTaskSpeedUp()
	if self.data.costVo == nil then
		return;
	end
	
	local haveCount = DataCenter.packData:getItemCountById(self.data.costVo.id);
	if haveCount >= self.data.costVo.count then
		Lua_ProxyManager.getProxy("Lua_MainLineProxy"):sTaskSpeedUp(self.data.uid);
	else
		DataCenter.packUtil:openPathWindow(self.data.costVo, false);
	end
end